==> haskell-dlist-1.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist
version:              1.0
visibility:           public
id:                   dlist-1.0-IuRZnuyPdTiETBc3ZAhsYV
key:                  dlist-1.0-IuRZnuyPdTiETBc3ZAhsYV
license:              BSD-3-Clause
copyright:
    2006-2009 Don Stewart, 2013-2020 Sean Leather, 2017-2020 Oleg Grenrus, contributors

maintainer:           Sean Leather <sean.leather@gmail.com>
author:               Don Stewart
homepage:             https://github.com/spl/dlist
synopsis:             Difference lists
description:          List-like types supporting O(1) append and snoc operations.
category:             Data
abi:                  c3772b82c5c0cfe98dde228f28b6126b
exposed:              True
exposed-modules:      Data.DList Data.DList.DNonEmpty Data.DList.Unsafe
hidden-modules:       Data.DList.Internal Data.DList.DNonEmpty.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dlist-1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dlist-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/dlist-1.0
hs-libraries:         HSdlist-1.0-IuRZnuyPdTiETBc3ZAhsYV
depends:              base-4.14.1.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html:         /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-1.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist
version:              1.0
visibility:           public
id:                   dlist-1.0-63RMXIsWIFWBS2JToLj2ZF
key:                  dlist-1.0-63RMXIsWIFWBS2JToLj2ZF
license:              BSD-3-Clause
copyright:
    2006-2009 Don Stewart, 2013-2020 Sean Leather, 2017-2020 Oleg Grenrus, contributors

maintainer:           Sean Leather <sean.leather@gmail.com>
author:               Don Stewart
homepage:             https://github.com/spl/dlist
synopsis:             Difference lists
description:          List-like types supporting O(1) append and snoc operations.
category:             Data
abi:                  cef97534db869324e7482de022222458
exposed:              True
exposed-modules:      Data.DList Data.DList.DNonEmpty Data.DList.Unsafe
hidden-modules:       Data.DList.Internal Data.DList.DNonEmpty.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dlist-1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dlist-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/dlist-1.0
hs-libraries:         HSdlist-1.0-63RMXIsWIFWBS2JToLj2ZF
depends:              base-4.14.1.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html:         /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
